Usage
optPenaltyCV(Y, lambdaMin, lambdaMax, step, type = "Alt", target =
diag(1/diag(covML(Y))), targetScale = TRUE, output = "light", graph = TRUE,
verbose = TRUE)
Arguments
Y
Data matrix. Variables assumed to be represented by columns.
lambdaMin
A numeric giving the minimum value for the penalty parameter.
lambdaMax
A numeric giving the maximum value for the penalty parameter.
step
An integer determining the number of steps in moving through the grid [lambdaMin, lambdaMax].
type
A character indicating the type of ridge estimator to be used. Must be one of: "Alt", "ArchI", "ArchII".
target
A target matrix (in precision terms) for Type I ridge estimators.
targetScale
A logical indicating if the default target is to be made dependent on the leave-one-out sample.
output
A character indicating if the output is either heavy or light. Must be one of: "all", "light".
graph
A logical indicating if the grid search for the optimal penalty parameter should be visualized.
verbose
A logical indicating if intermediate output should be printed on screen.