ridgeS(S, lambda, type = "Alt", target = diag(1/diag(S)))matrix.numeric representing the value of the penalty parameter.character indicating the type of ridge estimator to be used. Must be one of: "Alt", "ArchI", "ArchII".matrix (in precision terms) for Type I ridge estimators.matrix.lambda parameter in ridgeS generically indicates the penalty parameter. It must be chosen in accordance with the type of
ridge estimator employed. The domains for the penalty parameter in the archetypal estimators are given above. The domain for lambda in
the alternative estimators is $(0, \infty)$. The type parameter specifies the type of ridge estimator. Specifying type = "ArchI" leads
to usage of the archetypal I estimator while specifying type = "ArchII" leads to usage of the archetypal II estimator. Specifying type = "Alt"
enables usage of the alternative ridge estimators: when type = "Alt" and the target matrix is p.d. one obtains the alternative Type I estimator;
when type = "Alt" and the target matrix is specified to be the null-matrix one obtains the alternative Type II estimator.
The Type I estimators thus employ target shrinkage. The default target for both the archetype and alternative is diag(1/diag(S)). When target is
not the null-matrix it is expected to be p.d. for the alternative type I estimator. The target is always expected to be p.d. in case of the archetypal I estimator.## Obtain some (high-dimensional) data
p = 25
n = 10
set.seed(333)
X = matrix(rnorm(n*p), nrow = n, ncol = p)
colnames(X)[1:25] = letters[1:25]
Cx <- covML(X)
## Obtain regularized precision matrix
ridgeS(Cx, lambda = 10, type = "Alt")Run the code above in your browser using DataLab